<?php
/**
 * Plugin Name:       Group Buying for WooCommerce
 * Requires Plugins: woocommerce
 * Plugin URI:        https://woocommerce.com/products/addify-group-buy-for-woocommerce
 * Description:       Add group buying to your store! Allow your customers to purchase products together and receive a group-buy discount.
 * Version:           1.0.0
 * Author:            Addify
 * Developed By:      Addify
 * Author URI:        https://woocommerce.com/vendor/addify/
 * Support:           https://woocommerce.com/vendor/addify/
 * Domain Path:       /languages
 * Text Domain:       addify-group-buy-for-woocommerce
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
	* WC requires at least: 4.0
	* WC tested up to: 9.*.*
	* Requires at least: 6.5
	* Tested up to: 6.*.*
	* Requires PHP: 7.4
 *
 */

if (!defined('ABSPATH')) {
	exit();
}

if (!class_exists('Addify_Group_Buying')) {

	class Addify_Group_Buying {
	

		public function __construct() {
			$this->addify_gpby_global_constents_vars();
			add_action('plugin_loaded', array( $this, 'af_pc_plugin_loaded' ));
			add_action('before_woocommerce_init', array( $this, 'adf_gpby_wsp_HOPS_Compatibility' ));
			register_activation_hook(__FILE__, array( $this, 'adf_gpby_setting_save' ));

			include_once AF_GPBY_DIR . 'includes/main.php';
		}
		
		public function addify_gpby_global_constents_vars() {
			if (!defined('AF_GPBY_URL')) {
				define('AF_GPBY_URL', plugin_dir_url(__FILE__));
			}
			if (!defined('AF_GPBY_DIR')) {
				define('AF_GPBY_DIR', plugin_dir_path(__FILE__));
			}
		}

		public function adf_gpby_wsp_HOPS_Compatibility() {

			if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
				\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
			}
		}

		public function af_pc_plugin_loaded() {
			if ( function_exists('load_plugin_textdomain') ) {
				load_plugin_textdomain( 'addify-group-buy-for-woocommerce', false, AF_GPBY_DIR . '/languages' );

			}
		}

		public function adf_gpby_setting_save() {
			 
			$default_options = array(
				'adf_gpby_counter_option'      => 'counter',
				'gp_by_btn_lbl'                => 'Group buy',
				'buy_btn_txt_clr'              => '#ffffff',
				'buy_btn_bg_clr'               => '#333333',
				'crt_gp_btn_lbl'               => 'Create group',
				'crt_gp_btn_txt_clr'           => '#ffffff',
				'crt_gp_btn_bg_clr'            => '#333333',
				'plc_hold_bg_clr'              => '#5d89cf',
				'plc_hold_txt_clr'             => '#ffffff',
				'adf_gpby_order_stat'          => 'wc-on-hold',  
				'adf_gpby_term_condition'      => 'Group buy enabling you to purchase products in groups to earn massive discounts. Create or join a group and complete the required members count to earn discounts on group purchases.',
				'adf_gpby_term_condition_desc' => 'Group buying enables you to purchase products as a group and get discounts. Create or join a group, and you will receive a discounted product when the group sales target is achieved.',
				'crt_grp_place_holder_txt'     => 'Purchase the product from the group to make it public for other customers to participate.',
				'gp_by_accout_heading'         => 'All Groups',
				'gp_by_accout_dec'             => 'Following are the groups that you have either created, joined, or been invited to join.',
				'adf_gpby_enable_tab'          => false,
			);
		
			if (get_option('adf_gpby_general_settings') === false) {
				add_option('adf_gpby_general_settings', $default_options);
			}
		}
	}
	new Addify_Group_Buying();
}
