<?php

if (!defined('ABSPATH')) {
	exit();
}

if (!class_exists('Addify_Gpby_Add_Column')) :

	class Addify_Gpby_Add_Column {

		public function __construct() {
			add_action('admin_head', array( $this, 'hide_add_new_button' ));
			add_filter('manage_addify_gpinfo_posts_columns', array( $this, 'add_custom_columns' ));
			add_action('manage_addify_gpinfo_posts_custom_column', array( $this, 'custom_column_content' ), 10, 2); 
			add_action('woocommerce_admin_order_data_after_order_details', array( $this, 'update_group_id_meta_data' ));
		}


		public function hide_add_new_button() {
			global $post_type;
			
			if ('addify_gpinfo' === $post_type) {
				?>
				<script type="text/javascript">
					jQuery(document).ready(function ($) {
						$('.page-title-action').hide();
					});
				</script>    
				<?php
			}
		}

		public function add_custom_columns( $columns ) {
			return array(
				'cb'                => '<input type="checkbox" />',
				'title'             => __('Title', 'addify-group-buy-for-woocommerce'),
				'column_group_name' =>  __('Group Name', 'addify-group-buy-for-woocommerce'),
				'column_group_size' => __('Group Size', 'addify-group-buy-for-woocommerce'),
				'column_status'     =>  __('Status', 'addify-group-buy-for-woocommerce'),
				'date'              =>__( 'Date', 'addify-group-buy-for-woocommerce'),
			);
		}

		public function custom_column_content( $column_name, $post_id ) {
			switch ($column_name) {
				case 'column_status':
					echo '<div class="adf-gbby-status_column">' . esc_attr(ucfirst(get_post_meta($post_id, 'adf_gpby_group_info_status', true))) . '</div>';
					break;
				case 'column_group_size':
					echo esc_attr(get_post_meta($post_id, 'adf_gpif_group_member', true));
					break;
				case 'column_group_name':
					echo esc_attr(get_post_meta($post_id, 'adf_pgif_group_name', true));
					break;
			}
		}

		public function update_group_id_meta_data( $order ) {
			
			foreach ($order->get_items() as $item_id => $item) {
				$itemGroupId = $item->get_meta('buyGroupId');

				if (isset($itemGroupId) && !empty($itemGroupId)) :
					$getUrl = $this->getEditURl($itemGroupId);
					$item->update_meta_data('Group name', '<a href="' . esc_url($getUrl) . '">' . esc_html($item['Group name']) . '</a>');
				endif;

			}
		}

		public function getEditURl( $groupId ) {
			$args    = array(
				'post_type'      => 'addify_gpinfo',
				'posts_per_page' => -1,
				'post_status'    => 'publish',
				'meta_query'     => array(
					'relation' => 'AND',
					array(
						'key'     => 'adf_pgif_group_id',
						'value'   => $groupId,
						'compare' => '=',
					),
				),
			);
			$editUrl = null;
			$query   = new WP_Query($args);
			if ($query->have_posts()) : 
				while ($query->have_posts()) :
					$query->the_post();
					$post_id = get_the_ID();
					$editUrl = get_edit_post_link($post_id);
					break;
				endwhile;
			endif;
			return $editUrl;
		}
	}
	new Addify_Gpby_Add_Column();
endif;