<?php

if (!defined('ABSPATH')) {
	exit();
}


if (!class_exists('Addify_Gpby_Setting')) :
	class Addify_Gpby_Setting {
		public function __construct() {
			$this->include_hooks();
		}

		public function include_hooks() {
			add_action( 'admin_menu', array( $this, 'adf_gpby_settings_page' ));
			add_action( 'admin_init', array( $this, 'adf_gpby_setting_init' ));
			add_action('all_admin_notices', array( $this, 'adf_gpby_display_tabs' ), 5);
		}
	
		public function adf_gpby_display_tabs() {
			$screen = get_current_screen();

			if ($screen && in_array($screen->id, $this->adf_gpby_get_tab_screen_ids())) :
				$tabs = array(
					'gp_buying_rule'  => array(
						'title' => __('Group Buy Rules', 'addify-group-buy-for-woocommerce'), // title of tab
						'url'   => admin_url('edit.php?post_type=addify_gpby'), // Url of tab
					),

					'gp_info_rule'    => array(
						'title' => __('All Created Groups', 'addify-group-buy-for-woocommerce'), // title of tab
						'url'   => admin_url('edit.php?post_type=addify_gpinfo'), // Url of tab
					),

					'general_setting' => array(
						'title' => __('Setting', 'addify-group-buy-for-woocommerce'), // title of tab
						'url'   => admin_url('admin.php?page=group-settings'), // Url of tab
					),
					   
				);

				if (is_array($tabs)) { ?>
				<div class="wrap woocommerce">
					<h2 class="nav-tab-wrapper woo-nav-tab-wrapper">
							<?php 
							$current_tab = $this->adf_gpby_get_current_tab();

							foreach ($tabs as $id => $tab_data) {
								$class = $id === $current_tab ? array( 'nav-tab', 'nav-tab-active' ) : array( 'nav-tab' );
								printf('<a href="%1$s" class="%2$s">%3$s</a>', esc_url($tab_data['url']), implode(' ', array_map('sanitize_html_class', $class)), esc_html($tab_data['title']));
							} 
							?>
					</h2>
				</div>
					<?php 
				}

			endif;
		}

		public function adf_gpby_settings_page() {

			add_submenu_page(
			'woocommerce',
			'WooCommerce group buying setting',
			'Group Buying',
			'manage_options',
			'group-settings',
			array( $this, 'adf_options_page' ),
			5
			);
	
			global $pagenow, $typenow;


			$current_post_id = filter_input(INPUT_GET, 'post', FILTER_VALIDATE_INT);
			$current_page    = filter_input(INPUT_GET, 'page', FILTER_SANITIZE_FULL_SPECIAL_CHARS);

			if (( 'edit.php' === $pagenow && 'addify_gpby' === $typenow ) || ( 'post.php' === $pagenow && isset($current_post_id) && 'addify_gpby' === get_post_type( sanitize_text_field( wp_unslash($current_post_id )) ) )) :
				remove_submenu_page('woocommerce', 'group-settings');
				remove_submenu_page('woocommerce', 'edit.php?post_type=addify_gpinfo'); 
			elseif (( 'edit.php' === $pagenow && 'addify_gpinfo' === $typenow ) || ( 'post.php' === $pagenow && isset($current_post_id) && 'addify_gpinfo' === get_post_type( sanitize_text_field( wp_unslash($current_post_id )) ) )) :
				remove_submenu_page('woocommerce', 'group-settings');  
				remove_submenu_page('woocommerce', 'edit.php?post_type=addify_gpby'); 
			elseif ('admin.php' === $pagenow && isset($current_page) && 'group-settings' ===  sanitize_text_field( wp_unslash($current_page)) ) :
				remove_submenu_page('woocommerce', 'edit.php?post_type=addify_gpby');
				remove_submenu_page('woocommerce', 'edit.php?post_type=addify_gpinfo'); 
			else :
				remove_submenu_page('woocommerce', 'group-settings');
				remove_submenu_page('woocommerce', 'edit.php?post_type=addify_gpinfo');
			endif;
		}

		public function adf_gpby_get_tab_screen_ids() {
			$tabs_screens = array(
				'woocommerce_page_group-settings',
				'addify_gpby',
				'edit-addify_gpby',
				'addify_gpinfo',
				'edit-addify_gpinfo',
			);
			return $tabs_screens;
		}

		public function adf_gpby_get_current_tab() {
			$screen    = get_current_screen();
			$screen_id = $screen->id;
	
			switch ($screen_id) {
				case 'edit-addify_gpby':
					return 'gp_buying_rule';
				case 'addify_gpby':
					return 'gp_buying_rule';       
				case 'edit-addify_gpinfo':
					return 'gp_info_rule';
				case 'addify_gpinfo':
					return 'gp_info_rule';
				case 'woocommerce_page_group-settings':
					return 'general_setting';
			}
		}

		public function adf_gpby_setting_init() {
			register_setting('adf_general_set', 'adf_gpby_general_settings');

			add_settings_section(
			'adf_general_section',
			__('Group Buying Setting', 'addify-group-buy-for-woocommerce'),
			array( $this, 'adf_general_section_callback' ),
			'adf_general'
			);
			
			add_settings_field(
				'adf_gpby_enable_tab',
			__('Enable The "Group Buy" Tab in My Account Page', 'addify-group-buy-for-woocommerce'),
			array( $this, 'adf_gpby_enable_tab_fun' ),
			'adf_general',
			'adf_general_section'
			);
	
			add_settings_field(
			'adf_gpby_show_author_name',
			__('Show Group Creator Name', 'addify-group-buy-for-woocommerce'),
			array( $this, 'adf_gpby_show_author_name_fun' ),
			'adf_general',
			'adf_general_section'
			);

			add_settings_field( 
			'adf_gpby_group_timer_select', 
			__( 'Group Timer', 'addify-group-buy-for-woocommerce' ), 
			array( $this, 'adf_gpby_group_counter_opt' ),
			'adf_general', 
			'adf_general_section' 
			);

			add_settings_field( 
			'adf_gpby_group_btn_text', 
			__( 'Group Buy Button Text', 'addify-group-buy-for-woocommerce' ), 
			array( $this, 'adf_gpby_group_btn_text_fun' ),
			'adf_general', 
			'adf_general_section' 
			);

			add_settings_field( 
			'adf_gpby_color_btn_text', 
			__( 'Group Buy Button Text Color', 'addify-group-buy-for-woocommerce' ), 
			array( $this, 'adf_gpby_color_btn_text_fun' ),
			'adf_general', 
			'adf_general_section' 
			);

			add_settings_field( 
			'adf_gpby_bg_color_btn_text', 
			__( 'Group Buy Button Backgroung Color', 'addify-group-buy-for-woocommerce' ), 
			array( $this, 'adf_gpby_bg_color_btn_text_fun' ),
			'adf_general', 
			'adf_general_section' 
			);

			add_settings_field( 
			'adf_gpby_create_btn_text', 
			__( 'Create Group Button Text', 'addify-group-buy-for-woocommerce' ), 
			array( $this, 'adf_gpby_create_btn_text_fun' ),
			'adf_general', 
			'adf_general_section' 
			);

			add_settings_field( 
			'adf_ct_gp_color_btn_text', 
			__( 'Create Group Button Text Color', 'addify-group-buy-for-woocommerce' ), 
			array( $this, 'adf_ct_gp_color_btn_text_fun' ),
			'adf_general', 
			'adf_general_section' 
			);

			add_settings_field( 
			'adf_ct_gp_bg_color_btn_text', 
			__( 'Create Group Button Background Color', 'addify-group-buy-for-woocommerce' ), 
			array( $this, 'adf_ct_gp_bg_color_btn_text_fun' ),
			'adf_general', 
			'adf_general_section' 
			);

			add_settings_field( 
			'adf_gp_crt_plc_hold_text', 
			__( 'Group Creation Place Holder', 'addify-group-buy-for-woocommerce' ), 
			array( $this, 'adf_gp_crt_plc_hold_text_fun' ),
			'adf_general', 
			'adf_general_section' 
			);

			add_settings_field( 
			'adf_gp_crt_plc_hold_text_clr', 
			__( 'Group Creation Place Holder Text Color', 'addify-group-buy-for-woocommerce' ), 
			array( $this, 'adf_gp_crt_plc_hold_text_clr_fun' ),
			'adf_general', 
			'adf_general_section' 
			);

			add_settings_field( 
				'adf_gp_crt_plc_hold_bg_clr', 
				__( 'Group Creation Place Holder Bachground Color', 'addify-group-buy-for-woocommerce' ), 
				array( $this, 'adf_gp_crt_plc_hold_bg_clr_fun' ),
				'adf_general', 
				'adf_general_section' 
				);
			
			add_settings_field(
				'adf_gpby_default_status',
			__('Order Status', 'addify-group-buy-for-woocommerce'),
			array( $this, 'adf_gpby_default_status_fun' ),
			'adf_general',
			'adf_general_section'
			);

			add_settings_field(
			'adf_gpby_order_status',
			__('Set Order Status', 'addify-group-buy-for-woocommerce'),
			array( $this, 'adf_gpby_order_status_fun' ),
			'adf_general',
			'adf_general_section'
			);

			add_settings_field(
				'adf_gpby_payment_method',
				__('Payment Method', 'addify-group-buy-for-woocommerce'),
				array( $this, 'adf_gpby_payment_method_fun' ),
				'adf_general',
				'adf_general_section'
				);

			add_settings_field( 
			'adf_gpby_group_term_condition', 
			__( 'Tooltip Description', 'addify-group-buy-for-woocommerce' ), 
			array( $this, 'adf_gpby_group_term_func' ),
			'adf_general', 
			'adf_general_section' 
			);

			add_settings_field( 
				'adf_gpby_acc_headint_txt', 
				__( 'Add Heading', 'addify-group-buy-for-woocommerce' ), 
				array( $this, 'adf_gpby_group_acc_headint_txt' ),
				'adf_general', 
				'adf_general_section' 
			);

			add_settings_field( 
				'adf_gpby_acc_headint_dec', 
				__( 'Add Description', 'addify-group-buy-for-woocommerce' ), 
				array( $this, 'adf_gpby_group_acc_headint_dec' ),
				'adf_general', 
				'adf_general_section' 
			);
		}

		public function adf_gpby_enable_tab_fun() {
			$options = get_option('adf_gpby_general_settings');
			$checked = isset($options['adf_gpby_enable_tab']) &&  'true' === $options['adf_gpby_enable_tab'] ? 'checked' : '';
			?>
		<input type="checkbox" id="adf-gpby-progrss-bar" name="adf_gpby_general_settings[adf_gpby_enable_tab]" value="true" <?php echo esc_attr($checked); ?>>
		<?php
		}

		public function adf_gpby_show_author_name_fun() {
			$options = get_option('adf_gpby_general_settings');
			$checked = isset($options['adf_gpby_creater_name']) &&  'true' === $options['adf_gpby_creater_name'] ? 'checked' : '';
			?>
		<input type="checkbox" id="adf-gpby-progrss-bar" name="adf_gpby_general_settings[adf_gpby_creater_name]" value="true" <?php echo esc_attr($checked); ?>>
		<?php
		}

		public function adf_gpby_group_counter_opt() {
			$options        = get_option('adf_gpby_general_settings');
			$defaultCounter = isset($options['adf_gpby_counter_option'])  ? $options['adf_gpby_counter_option'] : 'counter';
			
			$options = array(
				'counter' => 'Counter Form',
				'text'    => 'Text Form',
			);
			?>
			<select id="adf_gpby_counter_option" name="adf_gpby_general_settings[adf_gpby_counter_option]">
				<?php foreach ($options as $value => $label) : ?>
					<option value="<?php echo esc_attr($value); ?>" <?php selected($defaultCounter, $value); ?>>
						<?php echo esc_html($label); ?>
					</option>
				<?php endforeach; ?>
			</select>
			<?php
		}

		public function adf_gpby_group_btn_text_fun() {
			$options = get_option('adf_gpby_general_settings');
			?>
			<input name="adf_gpby_general_settings[gp_by_btn_lbl]" class="" type="text" value="<?php echo ( isset($options['gp_by_btn_lbl']) ? esc_attr($options['gp_by_btn_lbl']) : 'group buy' ); ?>" />
		<?php
		}

		public function adf_gpby_color_btn_text_fun() {
			$options = get_option('adf_gpby_general_settings');
			?>
			<input name="adf_gpby_general_settings[buy_btn_txt_clr]" class="my-color-field" type="text" value="<?php echo ( isset($options['buy_btn_txt_clr']) ? esc_attr($options['buy_btn_txt_clr']) : '#ffffff' ); ?>" data-default-color="#ffffff" />
		<?php
		}

		public function adf_gpby_bg_color_btn_text_fun() {
			$options = get_option('adf_gpby_general_settings');
			?>
			<input name="adf_gpby_general_settings[buy_btn_bg_clr]" class="my-color-field" type="text" value="<?php echo ( isset($options['buy_btn_bg_clr']) ? esc_attr($options['buy_btn_bg_clr']) : '#333333' ); ?>" data-default-color="#333333" />
		<?php
		}

		public function adf_gpby_create_btn_text_fun() {
			$options = get_option('adf_gpby_general_settings');
			?>
			<input name="adf_gpby_general_settings[crt_gp_btn_lbl]" class="" type="text" value="<?php echo ( isset($options['crt_gp_btn_lbl']) ? esc_attr($options['crt_gp_btn_lbl']) : 'create group' ); ?>" />
		<?php
		}

		public function adf_ct_gp_color_btn_text_fun() {
			$options = get_option('adf_gpby_general_settings');
			?>
			<input name="adf_gpby_general_settings[crt_gp_btn_txt_clr]" class="my-color-field" type="text" value="<?php echo ( isset($options['crt_gp_btn_txt_clr']) ? esc_attr($options['crt_gp_btn_txt_clr']) : '#ffffff' ); ?>" data-default-color="#ffffff" />
		<?php
		}

		public function adf_ct_gp_bg_color_btn_text_fun() {
			$options = get_option('adf_gpby_general_settings');
			?>
			<input name="adf_gpby_general_settings[crt_gp_btn_bg_clr]" class="my-color-field" type="text" value="<?php echo ( isset($options['crt_gp_btn_bg_clr']) ? esc_attr($options['crt_gp_btn_bg_clr']) : '#333333' ); ?>" data-default-color="#333333" />
		<?php
		}

		public function adf_gp_crt_plc_hold_text_fun() {
			$options = get_option('adf_gpby_general_settings');
			?>
			<input name="adf_gpby_general_settings[crt_grp_place_holder_txt]" class="adf_gpby_sett_crt_plac_hold" type="text" value="<?php echo ( isset($options['crt_grp_place_holder_txt']) ? esc_attr($options['crt_grp_place_holder_txt']) : 'Purchase the product from the group to make it public for other customers to participate.' ); ?>" />
		<?php
		}

		public function adf_gp_crt_plc_hold_text_clr_fun() {
			$options = get_option('adf_gpby_general_settings');
			?>
			<input name="adf_gpby_general_settings[plc_hold_txt_clr]" class="my-color-field" type="text" value="<?php echo ( isset($options['plc_hold_txt_clr']) ? esc_attr($options['plc_hold_txt_clr']) : '#ffffff' ); ?>" data-default-color="#ffffff" />
		<?php
		}


		public function adf_gp_crt_plc_hold_bg_clr_fun() {
			$options = get_option('adf_gpby_general_settings');
			?>
			<input name="adf_gpby_general_settings[plc_hold_bg_clr]" class="my-color-field" type="text" value="<?php echo ( isset($options['plc_hold_bg_clr']) ? esc_attr($options['plc_hold_bg_clr']) : '#5d89cf' ); ?>" data-default-color="#5d89cf" />
		<?php
		}

		public function adf_gpby_default_status_fun() {

			$options = get_option('adf_gpby_general_settings');
			$checked = isset($options['adf_gpby_default_order_status']) &&  'true' === $options['adf_gpby_default_order_status'] ? 'checked' : '';
			?>
		<input type="checkbox" id="adf-gpby-defualt-status" name="adf_gpby_general_settings[adf_gpby_default_order_status]" value="true" <?php echo esc_attr($checked); ?>>
		<span><?php echo esc_html__('Enable it to set order status of group buying product.', 'addify-group-buy-for-woocommerce'); ?></span>
		<?php
		}

		public function adf_gpby_order_status_fun() {
	
			$options               = get_option('adf_gpby_general_settings');
			$orderStatus           = isset($options['adf_gpby_order_stat']) ? $options['adf_gpby_order_stat'] : 'wc-on-hold';
			$wc_get_order_statuses = wc_get_order_statuses();
			?>
			<select id="adf_gpby_order_stat" name="adf_gpby_general_settings[adf_gpby_order_stat]">
				<?php foreach ($wc_get_order_statuses as $value => $label) : ?>
					<option value="<?php echo esc_attr($value); ?>" <?php selected($orderStatus, $value); ?>>
						<?php echo esc_html($label); ?>
					</option>
				<?php endforeach; ?>
			</select>
			<?php
		}

		public function adf_gpby_payment_method_fun() {
	
			$options        = get_option('adf_gpby_general_settings');
			$paymentMethods = isset($options['adf_gpby_payment_method']) ? $options['adf_gpby_payment_method'] : '';
			$gateways       = $this->get_payment_gateways();
			?>
			<select class="adf-gpby-live-search-for" id="adf_gpby_payment_method" name="adf_gpby_general_settings[adf_gpby_payment_method][]" data-search_type = 'payment_method' multiple style="width:60%">
				<?php foreach ($gateways as $value => $label) : ?>
					<option value="<?php echo esc_attr($value); ?>" <?php echo ( is_array($paymentMethods) && in_array($value, $paymentMethods) ) ? 'selected' : ''; ?>>
						<?php echo esc_html($label); ?>
					</option>
				<?php endforeach; ?>
			</select>
			<div><i> <?php echo esc_html__('Select payment methods that can be used for a group purchase, or leave it empty to show all payment methods.', 'addify-group-buy-for-woocommerce'); ?></i></div>
			<?php
		}
		
	
		public function adf_gpby_group_term_func() {
			$options = get_option( 'adf_gpby_general_settings');
			$content = isset( $options['adf_gpby_term_condition'] ) ?  $options['adf_gpby_term_condition'] : false;
			wp_editor( $content, 'adf_gpby_term_condition', array( 
				'textarea_name' => 'adf_gpby_general_settings[adf_gpby_term_condition]',
				'media_buttons' => false,
				'textarea_rows' => 10,
			) );
		}
		
		public function adf_general_section_callback() {
			return;
		}

		public function adf_options_page() {
			?>
		<div class="wrap">
			<form action='options.php' method='post'>
				<?php
					settings_fields('adf_general_set');
					do_settings_sections('adf_general');
					submit_button();
				?>
			</form>
		</div>
			<?php
		}

		public function get_payment_gateways() {
			$payment_gateways = WC()->payment_gateways->get_available_payment_gateways();
			$gateways         = array();
	
			foreach ( $payment_gateways as $gateway_id => $gateway ) {
				$gateways[ $gateway_id ] =  $gateway->get_title() ;
			}
			
			return $gateways;
		}

		public function adf_gpby_group_acc_headint_txt() {
			$options = get_option('adf_gpby_general_settings');
			?>
			<input name="adf_gpby_general_settings[gp_by_accout_heading]" class="adf_gpby_sett_crt_plac_hold" type="text" value="<?php echo ( isset($options['gp_by_accout_heading']) ? esc_attr($options['gp_by_accout_heading']) : '' ); ?>" />
			<div><i><?php echo esc_html__('Add heading for group buy tab in "My account page".', 'addify-group-buy-for-woocommerce'); ?></i></div>
		<?php
		}

		public function adf_gpby_group_acc_headint_dec() {
			$options = get_option('adf_gpby_general_settings');
			?>
			<input name="adf_gpby_general_settings[gp_by_accout_dec]" class="adf_gpby_sett_crt_plac_hold" type="text" value="<?php echo ( isset($options['gp_by_accout_dec']) ? esc_attr($options['gp_by_accout_dec']) : '' ); ?>" />
			<div><i><?php echo esc_html__('Add description group buy tab in "My account page".', 'addify-group-buy-for-woocommerce'); ?></i></div>
		<?php
		}
	}
	new Addify_Gpby_Setting();
endif;