<?php

if (!class_exists('Adf_Gpby_Disqualified_Group_Email')) {

	class Adf_Gpby_Disqualified_Group_Email extends WC_Email {

		public function __construct() {
			
			$this->id             = 'adf_gpby_email_disqualified_group'; // Unique ID to Store Emails Settings
			$this->title          = __('Disqualified Group Email', 'addify-group-buy-for-woocommerce'); // Title of email to show in Settings
			$this->customer_email = true; // Set true for customer email and false for admin email.
			$this->description    = __('Email send to customer and admin both when group will be disqualified', 'addify-group-buy-for-woocommerce'); // description of email
			$this->template_base  = AF_GPBY_DIR; // Base directory of template 
			$this->template_html  = 'includes/email-template/html/adf_gpby_disqualify_mial_html.php'; // HTML template path
			$this->template_plain = 'includes/email-template/plain/adf_gpby_disqualify_mial_plain.php'; // Plain template path
			$this->placeholders   = array( // Placeholders/Variables to be used in email
				'{group_title}' =>'',
				'{product_url}' => '',
			);
			// Call to the  parent constructor.
			parent::__construct(); 
			// Trigger function  for this customer email.
			add_action('addify_gpby_group_disqualify', array( $this, 'trigger' ), 10, 2); // action hook(s) to trigger email 
		}

		/**
		 * Get email subject.
		 */
		public function get_default_subject() {
			return __('Notification: Your Group Buying Product Has Been Disqualified', 'addify-group-buy-for-woocommerce');
		}
		
		/**
		 * Retrieve the email heading.
		 */
		public function get_default_heading() {
			return __('Important Update: Your Group Buying Entry Has Been Disqualified', 'addify-group-buy-for-woocommerce');
		}

		/**
		 * Trigger the sending of this email.
		 */
		public function trigger( $new_form_data, $arge = null ) {
			$this->setup_locale();
			
			$this->placeholders['{group_title}'] =$new_form_data['group_title'] ;
			$this->placeholders['{product_url}'] =$new_form_data['product_url'] ;
			if ($this->is_enabled()) {
				foreach ($new_form_data['emails'] as $email) {
					$this->send($email, $this->get_subject(), $this->get_content(), $this->get_headers(), $this->get_attachments());
				}
			}
			$this->restore_locale();
		}

		/**
		 * Get content html.
		 */

		public function get_content_html() {
			return wc_get_template_html(
			$this->template_html,
			array(
				'group_title'        => $this->placeholders['{group_title}'],
				'product_url'        => $this->placeholders['{product_url}'],
				'email_heading'      => $this->get_heading(),
				'additional_content' => $this->get_additional_content(),
				'sent_to_admin'      => false,
				'plain_text'         => false,
				'email'              => $this,
			),
			$this->template_base,
			$this->template_base
			);
		}
		
		/**
		 * Get content plain.
		 */
		public function get_content_plain() {
			return wc_get_template_html(
			$this->template_html,
			array(
				'group_title'        => $this->placeholders['{group_title}'],
				'product_url'        => $this->placeholders['{product_url}'],
				'email_heading'      => $this->get_heading(),
				'additional_content' => $this->get_additional_content(),
				'sent_to_admin'      => false,
				'plain_text'         => false,
				'email'              => $this,
			),
			$this->template_base,
			$this->template_base
			);
		}

		/**
		 * Default content to show below main email content.
		 */

		public function get_default_additional_content() {
			return __( 'Unfortunity, group has been disqualified.', 'addify-group-buy-for-woocommerce');
		}
	}
}
