<?php

if (!class_exists('Adf_Gpby_Join_Email_Register')) {
	// code...
	class Adf_Gpby_Join_Email_Register extends WC_Email {


		public function __construct() {
			
			$this->id             = 'adf_gpby_email_join_group'; // Unique ID to Store Emails Settings
			$this->title          = __('Join Group Email', 'addify-group-buy-for-woocommerce'); // Title of email to show in Settings
			$this->customer_email = true; // Set true for customer email and false for admin email.
			$this->description    = __('Email send to customer and admin both when any customer join group', 'addify-group-buy-for-woocommerce'); // description of email
			$this->template_base  = AF_GPBY_DIR; // Base directory of template 
			$this->template_html  = 'includes/email-template/html/adf_gpby_join_group_mail_html.php'; // HTML template path
			$this->template_plain = 'includes/email-template/plain/adf_gpby_join_group_mail_plain.php'; // Plain template path
			$this->placeholders   = array( // Placeholders/Variables to be used in email
				'{group_title}'   =>'',
				'{product_url}'   => '',
				'{customer_name}' => '',
			);
			// Call to the  parent constructor.
			parent::__construct(); 
			// Trigger function  for this customer email.
			add_action('addify_gpby_join_new_member', array( $this, 'trigger' ), 10, 2); // action hook(s) to trigger email 
		}

		/**
		 * Get email subject.
		 */
		public function get_default_subject() {
			return __('New Member Joined Your Group', 'addify-group-buy-for-woocommerce');
		}

		/**
		 * Get email heading.
		 */
		public function get_default_heading() {
			return __('A New Member Has Joined the Group!', 'addify-group-buy-for-woocommerce');
		}

		/**
		 * Trigger the sending of this email.
		 */
		public function trigger( $new_form_data, $groupName = null ) {
			$this->setup_locale();
		
			$this->placeholders['{group_title}']   = $groupName ;
			$this->placeholders['{product_url}']   =$new_form_data['product_url'] ;
			$this->placeholders['{customer_name}'] =$new_form_data['customer_name'] ;

			if ($this->is_enabled()) {
				foreach ($new_form_data['emails'] as $email) {
					$this->send($email, $this->get_subject(), $this->get_content(), $this->get_headers(), $this->get_attachments());
				}
			}
			$this->restore_locale();
		}

		/**
		 * Get content html.
		 */

		public function get_content_html() {
			return wc_get_template_html(
			$this->template_html,
			array(
				'group_title'        => $this->placeholders['{group_title}'],
				'customer_name'      => $this->placeholders['{customer_name}'],
				'product_url'        => $this->placeholders['{product_url}'],
				'email_heading'      => $this->get_heading(),
				'additional_content' => $this->get_additional_content(),
				'sent_to_admin'      => true,
				'plain_text'         => false,
				'email'              => $this,
			),
			$this->template_base,
			$this->template_base
			);
		}
		
		/**
		 * Get content plain.
		 */
		public function get_content_plain() {
			return wc_get_template_html(
			$this->template_html,
			array(
				'group_title'        => $this->placeholders['{group_title}'],
				'customer_name'      => $this->placeholders['{customer_name}'],
				'product_url'        => $this->placeholders['{product_url}'],
				'email_heading'      => $this->get_heading(),
				'additional_content' => $this->get_additional_content(),
				'sent_to_admin'      => true,
				'plain_text'         => false,
				'email'              => $this,
			),
			$this->template_base,
			$this->template_base
			);
		}

		/**
		 * Default content to show below main email content.
		 */

		public function get_default_additional_content() {
			return __( 'A new member has joined the group. You can view the group details and manage it through your dashboard.', 'addify-group-buy-for-woocommerce' );
		}
	}
}
