<?php

if (!defined('ABSPATH')) {
	exit();
}

if (!class_exists('Adf_Gpby_Cart_Validation')) :

	class Adf_Gpby_Cart_Validation {

		public function __construct() {
			$this->adf_gpby_add_hook();
		}

		public function adf_gpby_add_hook() {
			add_filter( 'woocommerce_cart_item_price', array( $this, 'adf_gpby_change_item_price' ), 10, 3 );
			add_action('woocommerce_before_calculate_totals', array( $this, 'adf_gpby_before_add_to_Cart' ), 10, 1);
			add_filter( 'woocommerce_add_to_cart_validation', array( $this, 'adf_gpby_restrict_product_add_to_cart' ), 10, 3);
			add_action('woocommerce_checkout_create_order_line_item', array( $this, 'adf_gpby_add_custom_data_to_order_items' ), 10, 4);
			add_filter( 'woocommerce_available_payment_gateways', array( $this, 'adf_gpby_conditionally_hide_payment_gateways' ), 100, 1 );
			add_filter('woocommerce_after_cart_item_quantity_update', array( $this, 'adf_gpby_on_action_cart_updated' ), 20, 4);
			add_action('woocommerce_thankyou', array( $this, 'adf_gpby_add_group_Id' ), 10, 1); 
			add_filter( 'woocommerce_update_cart_validation', array( $this, 'restrict_cart_item_quantity' ), 10, 4 );
			add_filter('woocommerce_coupons_enabled', array( $this, 'disable_coupon_field_on_cart' ), 10); 
		}

		public function disable_coupon_field_on_cart( $enabled ) {
			if (!is_admin() && true === $this->adf_gpby_before_add_to_Cart(wc()->cart)) {
				$enabled = false;
			}
			return $enabled;
		}

		public function restrict_cart_item_quantity( $passed, $cart_item_key, $values, $quantity ) {

			$cart_item = WC()->cart->get_cart_item( $cart_item_key );

			$restrictQty = 'false';
			if ( isset( $cart_item['buyGroupId'] ) ) {
				$restrictQty = $this->restrictUserToJoin( $cart_item['buyGroupId'], $quantity );
			}
			
			if ( 'restrict' == $restrictQty ) {
				$max_quantity = 1;
				wc_add_notice( sprintf( 'You can only purchase a maximum of %d units of %s for group.', $max_quantity, $values['data']->get_name()), 'error' );
				$passed = false;
			}

			return $passed;
		}
		
		public function adf_gpby_before_add_to_Cart( $cart_object ) {
			
			$new_price           = -1;
			$is_discount_applied = false;
			foreach ($cart_object->get_cart() as $cart_item) {

				if (isset($cart_item['buyGroupId'])) {
					$GroupNumber = esc_html($cart_item['buyGroupId']);
				} else {
					continue;
				}
				
				$flag               = false;
				$adf_gpby_disc_type = 0;
				$product            = $cart_item['data'];
				if (0 === $cart_item['variation_id']) {
					$product_id = $cart_item['product_id'];
				} else {
					$product_id = 0;
					return;
				}
				
				$regular_price = $product->get_regular_price();
				$sales_price   = intval($product->get_sale_price());

				$args = array(
					'post_type'      => 'addify_gpinfo',
					'posts_per_page' => -1,
					'post_status'    => 'publish',
					'meta_query'     => array(
						'relation' => 'AND', 
						array(
							'key'     => 'adf_pgif_product_id',
							'value'   => $product_id,
							'compare' => '=',
						),
						array(
							'key'     => 'adf_pgif_group_id',
							'value'   => $GroupNumber,
							'compare' => '=',
						),
						array(
							'key'     => 'adf_gpby_group_info_status',
							'value'   => 'processing',
							'compare' => '=',
						),
					),
				);

				$query = new WP_Query($args);

				if ($query->have_posts()) :
					while ($query->have_posts()) :
						$query->the_post();
						$post_id = get_the_ID();
						
						$adf_gpby_disc_type            =  get_post_meta($post_id, 'adf_pgif_discount_type', true);
						$adf_gpby_price_type           =  get_post_meta($post_id, 'adf_gpby_group_info_prc_type', true);
						$expireDate                    =  get_post_meta($post_id, 'adf_pgif_group_exprire', true);
						$discountPrice                 =  get_post_meta($post_id, 'adf_pgif_group_price', true);
						$adf_gpby_group_discount_value = (int) str_replace('$', '', $discountPrice);
						$adf_gpby_group_discount_value = (int) str_replace('%', '', $discountPrice);
						
						if (isset($cart_item['groupId']) && $cart_item['groupId'] === $product_id && $adf_gpby_group_discount_value >= 0) :
							
							if ('percent' === $adf_gpby_disc_type) :
								if ('regprice' == $adf_gpby_price_type) :
									$new_price = $regular_price - ( ( $adf_gpby_group_discount_value/100 ) * $regular_price );
								elseif ('salprice' == $adf_gpby_price_type && !empty($sales_price)) :
									$new_price = $sales_price - ( ( $adf_gpby_group_discount_value/100 ) * $sales_price );
								endif;
							elseif ('fixed' === $adf_gpby_disc_type) :
								if ('regprice' == $adf_gpby_price_type) :
									$new_price = $regular_price - $adf_gpby_group_discount_value;
								elseif ('salprice' == $adf_gpby_price_type && !empty($sales_price)) :
									$new_price = $sales_price - $adf_gpby_group_discount_value;
								endif;
							endif;
							if ($new_price >= 0) :
								$cart_item['data']->set_price($new_price);
								$is_discount_applied = true;
							endif;
						endif;
					endwhile;
				endif;
			
			}

			return $is_discount_applied;
		}

		public function adf_gpby_change_item_price( $price, $cart_item, $cart_item_key ) {
			
			$new_price     = $cart_item['data']->get_price();
			$flag          = false;
			$discountPrice = null;
			$product       = $cart_item['data'];
			if (0 === $cart_item['variation_id']) {
				$product_id = $cart_item['product_id'];
			} else {
				return $price;
			}

			if (isset($cart_item['buyGroupId'])) {
				$GroupNumber = esc_html($cart_item['buyGroupId']);
			} else {
				return $price;
			}
			
			$regular_price = $cart_item['data']->get_regular_price();
			$sale_price    = $cart_item['data']->get_sale_price();

			$args = array(
				'post_type'      => 'addify_gpinfo',
				'posts_per_page' => -1,
				'post_status'    => 'publish',
				'meta_query'     => array(
					'relation' => 'AND',
					array(
						'key'     => 'adf_pgif_product_id',
						'value'   => $product_id,
						'compare' => '=',
					),
					array(
						'key'     => 'adf_pgif_group_id',
						'value'   => $GroupNumber,
						'compare' => '=',
					),
					array(
						'key'     => 'adf_gpby_group_info_status',
						'value'   => 'processing',
						'compare' => '=',
					),
				),
			);

			$query = new WP_Query($args);

			if ($query->have_posts()) :
				while ($query->have_posts()) :
					$query->the_post();
					$post_id = get_the_ID();

					$adf_gpby_disc_type            =  get_post_meta($post_id, 'adf_pgif_discount_type', true);
					$adf_gpby_price_type           =  get_post_meta($post_id, 'adf_gpby_group_info_prc_type', true);
					$expireDate                    =  get_post_meta($post_id, 'adf_pgif_group_exprire', true);
					$discountPrice                 =  get_post_meta($post_id, 'adf_pgif_group_price', true);
					$adf_gpby_group_discount_value = (int) str_replace('$', '', $discountPrice);
					$adf_gpby_group_discount_value = (int) str_replace('%', '', $discountPrice);
		
					if (isset($cart_item['groupId']) && $cart_item['groupId'] === $product_id && $adf_gpby_group_discount_value >= 0) :
						if ('percent' === $adf_gpby_disc_type) :
							if ('regprice' == $adf_gpby_price_type) :
								$new_price = $regular_price - ( ( $adf_gpby_group_discount_value/100 ) * $regular_price );
							elseif ('salprice' == $adf_gpby_price_type && !empty($sale_price)) :
								$new_price = $sale_price - ( ( $adf_gpby_group_discount_value/100 ) * $sale_price );
							endif;
						elseif ('fixed' === $adf_gpby_disc_type) :
							if ('regprice' == $adf_gpby_price_type) :
								$new_price = $regular_price - $adf_gpby_group_discount_value;
							elseif ('salprice' == $adf_gpby_price_type && !empty($sale_price)) :
								$new_price = $sale_price - $adf_gpby_group_discount_value;
							endif;
						endif;
						if ($new_price >= 0) :
							$cart_item['data']->set_price($new_price);
						endif;
						
					endif;
				endwhile;
			endif;
				  
			$price = wc_price($new_price); 
			return $price;
		}

	
		public function adf_gpby_add_custom_data_to_order_items( $item, $cart_item_key, $values, $order ) {
			if (isset($values['buyGroupId'])) {
				$item->add_meta_data('buyGroupId', $values['buyGroupId']);
				$getGroupName = $this->getGroupNameById($values['buyGroupId']);
	
				$item->add_meta_data('Group name', $getGroupName);
			}
		}

		public function getGroupNameById( $id ) {
			$agrs  = array(
				'post_type'     => 'addify_gpinfo',
				'post_per_page' => -1,
				'post_status'   => 'publish',
				'meta_query'    => array(
					array(
						'relation' => 'AND', 
						array(
							'key'     => 'adf_pgif_group_id',
							'value'   => $id,
							'compare' => '=',
						),
						array(
							'key'     => 'adf_gpby_group_info_status',
							'value'   => 'processing',
							'compare' => '=',
						),
					),
				),
			);
			$query = new WP_Query($agrs);

			if ($query->have_posts()) :
				$posts = $query->get_posts();

				foreach ($posts as $post) :
					$Name = get_post_meta($post->ID, 'adf_pgif_group_name', true);
				endforeach;

				return $Name;
			endif;

			return; 
		}
		public function adf_gpby_restrict_product_add_to_cart( $passed, $product_id, $quantity ) {

			foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) :
				if (isset($cart_item['groupId'])) :
					wc_add_notice( "First empty your cart, you can't add simple and group products together." , 'error' );
					return false;
				endif;
			endforeach;

			return true;
		}

		public function adf_gpby_add_group_Id( $order_id ) {
			
			if ( ! $order_id ) {
			return;
			}

			$orderThankYou = get_post_meta($order_id, 'adf_gpby_no_repeat_thankyou', true);
			if (isset($orderThankYou) && ( true == $orderThankYou || 1 == $orderThankYou )) {
				return;
			}

			if ( ! get_post_meta( $order_id, '_thankyou_action_done', true ) ) :

				$order = wc_get_order( $order_id );

				foreach ( $order->get_items() as $item_id => $item ) {

					$buyGroupId   = $item->get_meta('buyGroupId');
					$product      = $item->get_product();
					$product_id   = $product->get_id();
					$product_Name = $item->get_name();
					
					if ($buyGroupId) {
						$buyGroupCustmerData = null;
						$getSettingValue     = get_option('adf_gpby_general_settings');
						$defaultOrderStatus  = ( isset($getSettingValue['adf_gpby_default_order_status']) ? $getSettingValue['adf_gpby_default_order_status'] : false );
						
						if ($defaultOrderStatus) :
							$orderStatus = ( isset($getSettingValue['adf_gpby_order_stat']) ? $getSettingValue['adf_gpby_order_stat'] : 'wc-on-hold' );
							$order->update_status($orderStatus);
						endif;
						
						$firstName             = $order->get_billing_first_name();
						$currentDate           = current_datetime()->format('Y-m-d');
						$user_id               = get_current_user_id();
						$current_user          = wp_get_current_user();
						$userEmail             = $current_user->user_email;
						$buyGroupCustmerData[] = array( $currentDate, $firstName, $buyGroupId, $order_id, $user_id, $userEmail, $product_id ); 
						$this->addGroupInfoData($product_id, $buyGroupCustmerData, $item->get_quantity());
						$this->sendPrivateGroupEmail($buyGroupId, $product_id);
						$this->QualifyGroup($product_id, $buyGroupId);
						
					}            
				}
				$order->update_meta_data( '_thankyou_action_done', true );
				$order->save();
			endif;
			update_post_meta($order_id, 'adf_gpby_no_repeat_thankyou', true);
		}

		public function QualifyGroup( $product_id, $buyGroupId ) {
			$args = array(
				'post_type'      => 'addify_gpinfo',
				'posts_per_page' => -1,
				'post_status'    => 'publish',
				'meta_query'     => array(
					array(
						'relation' => 'AND', 
						array(
							'key'     => 'adf_pgif_product_id',
							'value'   => $product_id,
							'compare' => '=',
						),
						array(
							'key'     => 'adf_pgif_group_id',
							'value'   => $buyGroupId,
							'compare' => '=',
						),
						array(
							'key'     => 'adf_gpby_group_info_status',
							'value'   => 'processing',
							'compare' => '=',
						),
					),
				),
			);
		
			$query = new WP_Query($args);
			
			if ($query->have_posts()) :
				$posts = $query->get_posts(); // Retrieve the posts as an array
		
				foreach ($posts as $post) : // Use foreach instead of while
					$totalMember         = intval(get_post_meta($post->ID, 'adf_gpif_group_member', true));
					$getNumberOfcustomer = intval(get_post_meta($post->ID, 'adf_pgif_group_join_memeber', true));
		
					if ($totalMember == $getNumberOfcustomer) :
						update_post_meta($post->ID, 'adf_gpby_group_info_status', 'qualified');

						$groupInfoDatas = get_post_meta($post->ID, 'adf_pgif_join_group_member_info', true);
						if (is_array($groupInfoDatas)) :
							foreach ($groupInfoDatas as $groupInfoData) :
								$email[]          = $this->getEmailById($groupInfoData[4]);
								$productPermalink = $this->getProductParmlink($groupInfoData[6]);
							endforeach;

							$this->sendQualifyEmail($email, $productPermalink, $buyGroupId);
						endif;

					endif;
				endforeach;
			endif;
		}       

		public function addGroupInfoData( $product_id, $buyGroupCustmerData, $quantity ) {
			
			$emial[] = $buyGroupCustmerData[0][5];
			$args    = array(
				'post_type'      => 'addify_gpinfo',
				'posts_per_page' => -1,
				'post_status'    => 'publish',
				'meta_query'     => array(
					array(
						'relation' => 'AND', 
						array(
							'key'     => 'adf_pgif_product_id',
							'value'   => $product_id,
							'compare' => '=',
						),
						array(
							'key'     => 'adf_pgif_group_id',
							'value'   => $buyGroupCustmerData[0][2],
							'compare' => '=',
						),
						array(
							'key'     => 'adf_gpby_group_info_status',
							'value'   => 'processing',
							'compare' => '=',
						),
					),
				),
			);
	
			$query = new WP_Query($args);
			
			if ($query->have_posts()) :    
				
				while ($query->have_posts()) :
					$query->the_post();
					$post_id = get_the_ID();
					$user_id = get_current_user_id();
					$eee     = get_post_meta($post_id, 'adf_pgif_group_id', true);
				   
					$no_of_group_join_memeber = intval(get_post_meta($post_id, 'adf_pgif_group_join_memeber', true));
					$buyGroupCustmerDataDb    = get_post_meta($post_id, 'adf_pgif_join_group_member_info', true);
					$customerName             = $buyGroupCustmerData[0][1];
					if (is_array($buyGroupCustmerDataDb)) :
						foreach ($buyGroupCustmerDataDb as $data) :
							if (is_array($data)) :
								if (in_array($user_id, $data)) :
									update_post_meta($post_id, 'adf_order_showing', 'true');
									update_post_meta($post_id, 'adf_pgif_group_join_memeber', $no_of_group_join_memeber+$quantity);
									update_post_meta($post_id, 'adf_pgif_join_group_member_info', $buyGroupCustmerData);
									break;
								endif;
							endif;
						endforeach;
						
						$buyGroupCustmerData = array_merge($buyGroupCustmerDataDb, $buyGroupCustmerData);
					endif;
					if (isset($no_of_group_join_memeber)) :
						update_post_meta($post_id, 'adf_order_showing', 'true');
						update_post_meta($post_id, 'adf_pgif_group_join_memeber', $no_of_group_join_memeber+$quantity);
						update_post_meta($post_id, 'adf_pgif_join_group_member_info', $buyGroupCustmerData);
						$this->sendEmail($emial, $product_id, $buyGroupCustmerData, $customerName);
						break;
					else :
						update_post_meta($post_id, 'adf_order_showing', 'true');
						update_post_meta($post_id, 'adf_pgif_group_join_memeber', $quantity);
						update_post_meta($post_id, 'adf_pgif_join_group_member_info', $buyGroupCustmerData);
						$this->sendEmail($emial, $product_id, $buyGroupCustmerData, $customerName);
						break;
					endif;
				endwhile;
			endif;
		}

		public function adf_gpby_conditionally_hide_payment_gateways( $available_gateways ) {
			if ( is_admin() ) { 
				return $available_gateways;
			}
			$enabled_gateways = array();
			$getSettingValue  = get_option('adf_gpby_general_settings');
			$paymentMethod    = ( isset($getSettingValue['adf_gpby_payment_method']) ? $getSettingValue['adf_gpby_payment_method'] : array() );
			
			if (!empty(WC()->cart)) {
				foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
					if (isset($cart_item['buyGroupId'])) :
						$group_id = $cart_item['buyGroupId'];
						break;
					endif;
				}
			}
			
			if (isset($group_id) && !empty($group_id) && !empty($paymentMethod)) :
				$payment_gateways = WC()->payment_gateways->payment_gateways();
				if ( $payment_gateways ) {
					foreach ( $payment_gateways as $gateway ) {
						if (  'yes' == $gateway->enabled) {
							$enabled_gateways[] = $gateway->id;
						}
					}
				}
				$disallow_gateways = array_diff($enabled_gateways, $paymentMethod);         
			endif;
		
			if ( isset($disallow_gateways) && is_array($disallow_gateways) && !empty($disallow_gateways) ) {
				foreach ($disallow_gateways as $disallow_gateway) :
					unset($available_gateways[ $disallow_gateway ]);
				endforeach;
			}
			
			return $available_gateways;
		}
		
		public function get_current_user_role() {
			global $wp_roles;
			if ( is_user_logged_in() ) {
			$user  = wp_get_current_user();
			$roles = ( array ) $user->roles;
			$role  = $roles[0];
			return $role;
			} else {
			return 'guest';
			}
		}

		
		public function adf_gpby_on_action_cart_updated( $cart_item_key, $quantity, $old_quantity, $cart ) {
			static $already_run = false;
			if ( $already_run ) {
				return;
			}

			$already_run = true;
			$cart_item   = WC()->cart->get_cart_item( $cart_item_key );

			$restrictQty = 'false';
			if ( isset( $cart_item['buyGroupId'] ) ) {
				$restrictQty = $this->restrictUserToJoin( $cart_item['buyGroupId'], $quantity );
			}
			
			if ( 'restrict' == $restrictQty ) {
				wc_add_notice( ( 'You are allowed to add only one quantity of ' . $cart_item['data']->get_name() . '  to your cart.' ), 'error' );
				WC()->cart->set_quantity( $cart_item_key, $old_quantity);
			}
			
			if (is_array($restrictQty)) :
				
				if (in_array('true' , $restrictQty )) {
					wc_add_notice( ( 'Increase product to group size limit, you can only add maximum ' . $restrictQty[1] . ' qunatity of ' . $cart_item['data']->get_name() . ' product' ), 'error' );
					WC()->cart->set_quantity( $cart_item_key, $old_quantity );
				}
			endif;
		}

		public function restrictUserToJoin( $groupId, $quantity ) { 
			$args    = array(
				'post_type'      => 'addify_gpinfo',
				'posts_per_page' => -1,
				'post_status'    => 'publish',
				'meta_query'     => array(
					'relation' => 'AND',
					array(
						'key'     => 'adf_pgif_group_id',
						'value'   => $groupId,
						'compare' => '=',
					),
					array(
						'key'     => 'adf_gpby_group_info_status',
						'value'   => 'processing',
						'compare' => '=',
					),
				),
			);
			$editUrl = null;
			$query   = new WP_Query($args);
			
			if ($query->have_posts()) : 
				while ($query->have_posts()) :
					$query->the_post();
					$post_id = get_the_ID();
					
					$countMemeber         = intval(get_post_meta($post_id, 'adf_pgif_group_join_memeber', true));
					$groupSize            = intval(get_post_meta($post_id, 'adf_gpif_group_member', true));
					$allowSinngleCustomer = get_post_meta($post_id, 'adf_gpif_allow_sing_customer', true);
				
					if (isset($allowSinngleCustomer) && null != $allowSinngleCustomer) :
						if ('true' == $allowSinngleCustomer) :
							return 'restrict';
						endif;
					endif;

					if ($quantity+$countMemeber > $groupSize) :
						return array( 'true', $groupSize-$countMemeber );
					endif;

				endwhile;
			endif;
			return 'false';
		}

		public function sendEmail( $emails, $productId, $buyGroupCustomerData, $customerName ) {

			$productLink   = getProductParmlink($productId);
			$sendEmails[]  = get_option('admin_email');
			$new_form_data = array(
				'group_title'   => $buyGroupCustomerData[0][2],
				'product_url'   => esc_url($productLink),
				'customer_name' => $customerName,
				'emails'        => $sendEmails,
			);

			$groupTitle = $new_form_data['group_title'];



			$current_user = wp_get_current_user();
			$userEmail    = $current_user->user_email;
			$userID       = $current_user->ID; 

			$productLink = getProductParmlink($productId);

			$allPost = array(
				'post_type'      => 'addify_gpinfo',
				'posts_per_page' => -1,
				'post_status'    => 'publish',
				'meta_query'     => array(
					'relation' => 'AND',
					array(
						'key'     => 'adf_pgif_group_id',
						'value'   => $groupTitle,
						'compare' => '=',
					),
				),
			);

			$query = new WP_Query($allPost);

			if ($query->have_posts()) :

				while ($query->have_posts()) :
					$query->the_post();
					$post_id   = get_the_ID();
					$groupName = get_post_meta($post_id, 'adf_pgif_group_name', true);
				endwhile;

			endif;

			WC()->mailer()->emails['Adf_Gpby_Join_Email_Register']->trigger($new_form_data, $groupName);
		}

		public function sendPrivateGroupEmail( $buyGroupId, $productId ) {
			
			$current_user = wp_get_current_user();
			$userEmail    = $current_user->user_email;
			$userID       = $current_user->ID; 

			$productLink = getProductParmlink($productId);

			$allPost = array(
				'post_type'      => 'addify_gpinfo',
				'posts_per_page' => -1,
				'post_status'    => 'publish',
				'meta_query'     => array(
					'relation' => 'AND',
					array(
						'key'     => 'adf_pgif_group_id',
						'value'   => $buyGroupId,
						'compare' => '=',
					),
					array(
						'key'     => 'adf_gpby_group_info_status',
						'value'   => 'processing',
						'compare' => '=',
					),
					array(
						'key'     => 'adf_pgif_group_type',
						'value'   => 'private',
						'compare' => '=',
					),
					array(
						'key'     => 'adf_pgif_user_id',
						'value'   => $userID,
						'compare' => '=',
					),
				),
			);

			$query = new WP_Query($allPost);

			if ($query->have_posts()) : 
				while ($query->have_posts()) :
					$query->the_post();
					$post_id = get_the_ID();
					
					$emails           = get_post_meta($post_id, 'adf_gpby_group_allow_users', true);
					$sendEmailAlready = get_post_meta($post_id, 'adf_gpif_send_private_email', true);
					if (!isset($sendEmailAlready) || false == $sendEmailAlready) {
						if (isset($userEmail)) :
							$key = array_search($userEmail, $emails);

							if (false !== $key) {
								unset($emails[ $key ]);
							}
						endif;

						$emails        = array_unique($emails);
						$new_form_data = array(
							'product_url' => esc_url($productLink),
							'emails'      => $emails,
						);
						update_post_meta($post_id, 'adf_gpif_send_private_email', true);
						WC()->mailer()->emails['Adf_Gpby_Private_Group_Email']->trigger($new_form_data );
					}
				endwhile;
			endif;
		}
		
		public function getEmailById( $id ) {
			$current_user_data = get_userdata($id);
			$user_email        = $current_user_data->user_email;
			return $user_email;
		}

		public function getProductParmlink( $id ) {
			$link = get_permalink( $id );
			return $link;
		}

		public function sendQualifyEmail( $emails, $productLinks, $groupName ) {

			array_push($emails, get_option('admin_email'));
			$emails        = array_unique($emails);
			$new_form_data = array(
				'product_url' => esc_url($productLinks),
				'group_title' => esc_html($groupName),
				'emails'      => $emails,
			);

			WC()->mailer()->emails['Adf_Gpby_Qualified_Group_Email']->trigger($new_form_data );
		}
	}
	new Adf_Gpby_Cart_Validation();
endif;
